package mediarange_test

import (
	"sourcecode.social/reiver/go-httpaccept/mediarange"

	"testing"
)

func TestMediaRange_SubType(t *testing.T) {

	tests := []struct{
		MediaRange mediarange.MediaRange
		Expected string
	}{
		{
			MediaRange: mediarange.Create(""  ,  ""),
			Expected:                            "*",
		},



		{
			MediaRange: mediarange.Create("*"  ,  "*"),
			Expected:                             "*",
		},



		{
			MediaRange: mediarange.Create("application"  ,  ""),
			Expected:                                       "*",
		},
		{
			MediaRange: mediarange.Create("audio"  ,  ""),
			Expected:                                 "*",
		},
		{
			MediaRange: mediarange.Create("font"  ,  ""),
			Expected:                                "*",
		},
		{
			MediaRange: mediarange.Create("image"  ,  ""),
			Expected:                                 "*",
		},
		{
			MediaRange: mediarange.Create("text"  ,  ""),
			Expected:                                "*",
		},
		{
			MediaRange: mediarange.Create("video"  ,  ""),
			Expected:                                 "*",
		},
		{
			MediaRange: mediarange.Create("xyz"  ,  ""),
			Expected:                               "*",
		},



		{
			MediaRange: mediarange.Create("application"  ,  "*"),
			Expected:                                       "*",
		},
		{
			MediaRange: mediarange.Create("audio"  ,  "*"),
			Expected:                                 "*",
		},
		{
			MediaRange: mediarange.Create("font"  ,  "*"),
			Expected:                                "*",
		},
		{
			MediaRange: mediarange.Create("image"  ,  "*"),
			Expected:                                 "*",
		},
		{
			MediaRange: mediarange.Create("text"  ,  ""),
			Expected:                                "*",
		},
		{
			MediaRange: mediarange.Create("video"  ,  ""),
			Expected:                                 "*",
		},
		{
			MediaRange: mediarange.Create("xyz"  ,  ""),
			Expected:                               "*",
		},



		{
			MediaRange: mediarange.Create("Application"  ,  "*"),
			Expected:                                       "*",
		},
		{
			MediaRange: mediarange.Create("Audio"  ,  "*"),
			Expected:                                 "*",
		},
		{
			MediaRange: mediarange.Create("Font"  ,  "*"),
			Expected:                                "*",
		},
		{
			MediaRange: mediarange.Create("Image"  ,  "*"),
			Expected:                                 "*",
		},
		{
			MediaRange: mediarange.Create("Text"  ,  ""),
			Expected:                                "*",
		},
		{
			MediaRange: mediarange.Create("Video"  ,  ""),
			Expected:                                 "*",
		},
		{
			MediaRange: mediarange.Create("Xyz"  ,  ""),
			Expected:                               "*",
		},



		{
			MediaRange: mediarange.Create("APPLICATION"  ,  "*"),
			Expected:                                       "*",
		},
		{
			MediaRange: mediarange.Create("AUDIO"  ,  "*"),
			Expected:                                 "*",
		},
		{
			MediaRange: mediarange.Create("FONT"  ,  "*"),
			Expected:                                "*",
		},
		{
			MediaRange: mediarange.Create("IMAGE"  ,  "*"),
			Expected:                                 "*",
		},
		{
			MediaRange: mediarange.Create("TEXT"  ,  ""),
			Expected:                                "*",
		},
		{
			MediaRange: mediarange.Create("VIDEO"  ,  ""),
			Expected:                                 "*",
		},
		{
			MediaRange: mediarange.Create("XYZ"  ,  ""),
			Expected:                               "*",
		},



		{
			MediaRange: mediarange.Create("application"  ,  "activity+json"),
			Expected:                                       "activity+json",
		},
		{
			MediaRange: mediarange.Create("application"  ,  "epub+zip"),
			Expected:                                       "epub+zip",
		},
		{
			MediaRange: mediarange.Create("application"  ,  "gzip"),
			Expected:                                       "gzip",
		},
		{
			MediaRange: mediarange.Create("application"  ,  "java-archive"),
			Expected:                                       "java-archive",
		},
		{
			MediaRange: mediarange.Create("application"  ,  "json"),
			Expected:                                       "json",
		},
		{
			MediaRange: mediarange.Create("application"  ,  "ld+json"),
			Expected:                                       "ld+json",
		},
		{
			MediaRange: mediarange.Create("application"  ,  "pdf"),
			Expected:                                       "pdf",
		},
		{
			MediaRange: mediarange.Create("application"  ,  "msword"),
			Expected:                                       "msword",
		},
		{
			MediaRange: mediarange.Create("application"  ,  "octet-stream"),
			Expected:                                       "octet-stream",
		},
		{
			MediaRange: mediarange.Create("application"  ,  "ogg"),
			Expected:                                       "ogg",
		},
		{
			MediaRange: mediarange.Create("application"  ,  "rtf"),
			Expected:                                       "rtf",
		},
		{
			MediaRange: mediarange.Create("application"  ,  "vnd.oasis.opendocument.spreadsheet"),
			Expected:                                       "vnd.oasis.opendocument.spreadsheet",
		},
		{
			MediaRange: mediarange.Create("application"  ,  "vnd.openxmlformats-officedocument.wordprocessingml.document"),
			Expected:                                       "vnd.openxmlformats-officedocument.wordprocessingml.document",
		},
		{
			MediaRange: mediarange.Create("application"  ,  "vnd.mozilla.xul+xml"),
			Expected:                                       "vnd.mozilla.xul+xml",
		},
		{
			MediaRange: mediarange.Create("application"  ,  "vnd.ms-excel"),
			Expected:                                       "vnd.ms-excel",
		},
		{
			MediaRange: mediarange.Create("application"  ,  "x-7z-compressed"),
			Expected:                                       "x-7z-compressed",
		},
		{
			MediaRange: mediarange.Create("application"  ,  "x-bzip"),
			Expected:                                       "x-bzip",
		},
		{
			MediaRange: mediarange.Create("application"  ,  "x-bzip2"),
			Expected:                                       "x-bzip2",
		},
		{
			MediaRange: mediarange.Create("application"  ,  "x-cdf"),
			Expected:                                       "x-cdf",
		},
		{
			MediaRange: mediarange.Create("application"  ,  "x-csh"),
			Expected:                                       "x-csh",
		},
		{
			MediaRange: mediarange.Create("application"  ,  "x-freearc"),
			Expected:                                       "x-freearc",
		},
		{
			MediaRange: mediarange.Create("application"  ,  "x-httpd-php"),
			Expected:                                       "x-httpd-php",
		},
		{
			MediaRange: mediarange.Create("application"  ,  "x-sh"),
			Expected:                                       "x-sh",
		},
		{
			MediaRange: mediarange.Create("application"  ,  "x-tar"),
			Expected:                                       "x-tar",
		},
		{
			MediaRange: mediarange.Create("application"  ,  "xhtml+xml"),
			Expected:                                       "xhtml+xml",
		},



		{
			MediaRange: mediarange.Create("audio"  ,  "aac"),
			Expected:                                 "aac",
		},
		{
			MediaRange: mediarange.Create("audio"  ,  "midi"),
			Expected:                                 "midi",
		},
		{
			MediaRange: mediarange.Create("audio"  ,  "mpeg"),
			Expected:                                 "mpeg",
		},
		{
			MediaRange: mediarange.Create("audio"  ,  "ogg"),
			Expected:                                 "ogg",
		},
		{
			MediaRange: mediarange.Create("audio"  ,  "opus"),
			Expected:                                 "opus",
		},
		{
			MediaRange: mediarange.Create("audio"  ,  "wav"),
			Expected:                                 "wav",
		},
		{
			MediaRange: mediarange.Create("audio"  ,  "webm"),
			Expected:                                 "webm",
		},
		{
			MediaRange: mediarange.Create("audio"  ,  "3gpp"),
			Expected:                                 "3gpp",
		},
		{
			MediaRange: mediarange.Create("audio"  ,  "3gpp2"),
			Expected:                                 "3gpp2",
		},
		{
			MediaRange: mediarange.Create("audio"  ,  "x-midi"),
			Expected:                                 "x-midi",
		},



		{
			MediaRange: mediarange.Create("font"  ,  "ttf"),
			Expected:                                "ttf",
		},



		{
			MediaRange: mediarange.Create("image"  ,  "avif"),
			Expected:                                 "avif",
		},
		{
			MediaRange: mediarange.Create("image"  ,  "bmp"),
			Expected:                                 "bmp",
		},
		{
			MediaRange: mediarange.Create("image"  ,  "gif"),
			Expected:                                 "gif",
		},
		{
			MediaRange: mediarange.Create("image"  ,  "png"),
			Expected:                                 "png",
		},
		{
			MediaRange: mediarange.Create("image"  ,  "tiff"),
			Expected:                                 "tiff",
		},



		{
			MediaRange: mediarange.Create("text"  ,  "css"),
			Expected:                                "css",
		},
		{
			MediaRange: mediarange.Create("text"  ,  "csv"),
			Expected:                                "csv",
		},
		{
			MediaRange: mediarange.Create("text"  ,  "html"),
			Expected:                                "html",
		},
		{
			MediaRange: mediarange.Create("text"  ,  "javascript"),
			Expected:                                "javascript",
		},
		{
			MediaRange: mediarange.Create("text"  ,  "markdown"),
			Expected:                                "markdown",
		},
		{
			MediaRange: mediarange.Create("text"  ,  "plain"),
			Expected:                                "plain",
		},
		{
			MediaRange: mediarange.Create("text"  ,  "x-markdown"),
			Expected:                                "x-markdown",
		},



		{
			MediaRange: mediarange.Create("video"  ,  "3gpp2"),
			Expected:                                 "3gpp2",
		},
		{
			MediaRange: mediarange.Create("video"  ,  "ogg"),
			Expected:                                 "ogg",
		},
		{
			MediaRange: mediarange.Create("video"  ,  "mp2t"),
			Expected:                                 "mp2t",
		},
		{
			MediaRange: mediarange.Create("video"  ,  "mp4"),
			Expected:                                 "mp4",
		},
		{
			MediaRange: mediarange.Create("video"  ,  "mpeg"),
			Expected:                                 "mpeg",
		},
		{
			MediaRange: mediarange.Create("video"  ,  "webm"),
			Expected:                                 "webm",
		},
		{
			MediaRange: mediarange.Create("video"  ,  "x-msvideo"),
			Expected:                                 "x-msvideo",
		},



		{
			MediaRange: mediarange.Create("application"  ,  "ACTIVITY+JSON"),
			Expected:                                       "activity+json",
		},
		{
			MediaRange: mediarange.Create("audio"  ,  "MPEG"),
			Expected:                                 "mpeg",
		},
		{
			MediaRange: mediarange.Create("font"  ,  "TTF"),
			Expected:                                "ttf",
		},
		{
			MediaRange: mediarange.Create("image"  ,  "PNG"),
			Expected:                                 "png",
		},
		{
			MediaRange: mediarange.Create("text"  ,  "HTML"),
			Expected:                                "html",
		},
		{
			MediaRange: mediarange.Create("video"  ,  "OGG"),
			Expected:                                 "ogg",
		},
		{
			MediaRange: mediarange.Create("xyz"  ,  "BANANA"),
			Expected:                               "banana",
		},



		{
			MediaRange: mediarange.Create("*"  ,  ""),
			Expected:                             "*",
		},
		{
			MediaRange: mediarange.Create("*"  ,  "apple"),
			Expected:                             "*",
		},
		{
			MediaRange: mediarange.Create("*"  ,  "BANANA"),
			Expected:                             "*",
		},
		{
			MediaRange: mediarange.Create("*"  ,  "Cherry"),
			Expected:                             "*",
		},
		{
			MediaRange: mediarange.Create("*"  ,  "gif"),
			Expected:                             "*",
		},
		{
			MediaRange: mediarange.Create("*"  ,  "html"),
			Expected:                             "*",
		},
		{
			MediaRange: mediarange.Create("*"  ,  "javascript"),
			Expected:                             "*",
		},
		{
			MediaRange: mediarange.Create("*"  ,  "json"),
			Expected:                             "*",
		},
		{
			MediaRange: mediarange.Create("*"  ,  "png"),
			Expected:                             "*",
		},
		{
			MediaRange: mediarange.Create("*"  ,  "webm"),
			Expected:                             "*",
		},
		{
			MediaRange: mediarange.Create("*"  ,  "xml"),
			Expected:                             "*",
		},
	}

	for testNumber, test := range tests {

		actual := test.MediaRange.SubType()
		expected := test.Expected

		if expected != actual {
			t.Errorf("For test #%d, the actual canonical-subtype is not what was expected.", testNumber)
			t.Logf("MEDIA-RANGE: %#v", test.MediaRange)
			t.Logf("EXPECTED: %q", expected)
			t.Logf("ACTUAL:   %q", actual)
			continue
		}
	}
}
